# Portal Python SDK
Development tools for interfacting with PORTAL from Python

### Installation

``` pip install slink-pyortal ```

## Running Examples

### Move into examples folder

``` cd examples ```

### Configure Environment

Copy the sample enviornment file to the active version

``` cp .env.samples .env ```

Set values according to your local environment

### Run desired example

```./single_drone_one_way_mission.py ```

Follow instructions on command line to run the example